@@ -42,12 +42,18 @@ from validators import url, ValidationFailure
     u'http://مثال.إختبار',
     u'http://例子.测试',
     u'http://उदाहरण.परीक्षा',
+    u'http://www.😉.com',
+    u'http://😉.com/😁',
+    u'http://উদাহরণ.বাংলা',
+    u'http://xn--d5b6ci4b4b3a.xn--54b7fta0cc',
     u'http://-.~_!$&\'()*+,;=:%40:80%2f::::::@example.com',
     u'http://1337.net',
     u'http://a.b-c.de',
     u'http://223.255.255.254',
+    u'http://10.1.1.0',
     u'http://10.1.1.1',
     u'http://10.1.1.254',
+    u'http://10.1.1.255',
     u'http://127.0.0.1:8080',
     u'http://127.0.10.150',
     u'http://localhost',
@@ -114,8 +120,6 @@ def test_returns_true_on_valid_public_url(address, public):
     'http://-a.b.co',
     'http://a.b-.co',
     'http://0.0.0.0',
-    'http://10.1.1.0',
-    'http://10.1.1.255',
     'http://224.1.1.1',
     'http://1.1.1.1.1',
     'http://123.123.123',
